@@ -1,3 +1,17 @@
+#  Copyright 2021 The Funnel Rocket Maintainers
+#
+#  Licensed under the Apache License, Version 2.0 (the "License");
+#  you may not use this file except in compliance with the License.
+#  You may obtain a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+#  Unless required by applicable law or agreed to in writing, software
+#  distributed under the License is distributed on an "AS IS" BASIS,
+#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#  See the License for the specific language governing permissions and
+#  limitations under the License.
+
 import math
 import time
 from dataclasses import dataclass, field
@@ -19,6 +33,8 @@ from tests.utils.dataset_utils import TestDatasetInfo, DEFAULT_GROUP_COLUMN, DEF
     BASE_TIME, DEFAULT_GROUP_COUNT, DEFAULT_ROW_COUNT, new_test_dataset
 # noinspection PyUnresolvedReferences
 from tests.utils.redis_fixture import init_test_redis_settings
+# noinspection PyUnresolvedReferences
+from tests.utils.lambda_fixture import init_mock_lambda_settings
 
 # TODO skip this whole module if no docker env/processes running - using a class?
 # TODO test query/register timeout (sync/async)
